package com.zipline.back.controller;

import com.zipline.back.dao.CommentRepository;
import com.zipline.back.dao.PostRepository;
import com.zipline.back.dao.UserRepository;
import com.zipline.back.model.Comment;
import com.zipline.back.model.User;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.rest.webmvc.ResourceNotFoundException;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;

@RestController
public class CommentController {
    @Autowired
    CommentRepository commentRepo;
    @Autowired
    PostRepository postRepo;
    @Autowired
    UserRepository userRepo;

    @PostMapping(value="/post/{postId}/comment/{githubId}")
    @ResponseStatus(HttpStatus.OK)
    public Comment addComment (
            @PathVariable String githubId,
            @PathVariable Integer postId,
            @RequestBody Comment comment
    ) {
        User user = userRepo.findByGithubId(githubId);
        return postRepo.findById(postId).map(post -> {
          comment.setSender(user.getName());
          comment.setPost(post);
          comment.setTimestamp(LocalDateTime.now());
          return commentRepo.save(comment);
        }).orElseThrow(() -> new ResourceNotFoundException("Post was not found"));
    }

    @GetMapping(value="/comment/{postId}")
    public Iterable<Comment> findAllComments (
            @PathVariable Integer postId
    ) {
        return commentRepo.findAllByPostId(postId);
    }

}
